Coverage for modules/box__bizhelp/appointment/models.py: 100%

# Coverage for modules/box__bizhelp/appointment/models.py : 100%

## 8 statements

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 from init import db

2

3

4 class Appointments(db.Model):

5 __tablename__ = "appointments"

6 id = db.Column(db.Integer, primary_key=True)

7 name = db.Column(db.String(100))

8 date = db.Column(db.String(20))

9 time = db.Column(db.String(20))

10 active = db.Column(db.String(20))